from setuptools import setup

PACKAGE_NAME = "pyplotdesigner"

setup(name=PACKAGE_NAME,
      version="2023.1.1",
      description="",
      url="https://github.com/gnwong/pyplotdesigner",
      author="George N. Wong",
      author_email="gnwong@ias.edu",
      license="MIT",
      packages=["pyplotdesigner"])

